
# This file was generated by 'versioneer.py' (0.13) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

version_version = '0.9.3'
version_full = 'c1396618687f3eb13ef7d57990c2f8b79a67ab3d'
def get_versions(default={}, verbose=False):
    return {'version': version_version, 'full': version_full}

